@@ -40,11 +40,11 @@ class YouGetTests(unittest.TestCase):
     def test_acfun(self):
         acfun.download('https://www.acfun.cn/v/ac11701912', info_only=True)
 
-    def test_soundcloud(self):
+    #def test_soundcloud(self):
         ## single song
-        soundcloud.download(
-            'https://soundcloud.com/keiny-pham/impure-bird', info_only=True
-        )
+        #soundcloud.download(
+        #    'https://soundcloud.com/keiny-pham/impure-bird', info_only=True
+        #)
         ## playlist
         #soundcloud.download(
         #    'https://soundcloud.com/anthony-flieger/sets/cytus', info_only=True
